@@ -1,12 +1,12 @@
 #! /bin/sh -e
-# /usr/lib/emacsen-common/packages/install/ispack-ifc8.1
+# /usr/lib/emacsen-common/packages/install/ispack-fftw2-ifc9
 
 # Written by Jim Van Zandt <jrv@vanzandt.mv.com>, borrowing heavily
 # from the install scripts for gettext by Santiago Vila
 # <sanvila@ctv.es> and octave by Dirk Eddelbuettel <edd@debian.org>.
 
 FLAVOR=$1
-PACKAGE=ispack-ifc8.1
+PACKAGE=ispack-fftw2-ifc9
 
 if [ ${FLAVOR} = emacs ]; then exit 0; fi
 
