@@ -1,13 +1,13 @@
 #!/bin/sh -e
-# /usr/lib/emacsen-common/packages/remove/ispack-ifc8.1
+# /usr/lib/emacsen-common/packages/remove/ispack-fftw2-ifc9
 
 FLAVOR=$1
-PACKAGE=ispack-ifc8.1
+PACKAGE=ispack-fftw2-ifc9
 
 if [ ${FLAVOR} != emacs ]; then
     if test -x /usr/sbin/install-info-altdir; then
         echo remove/${PACKAGE}: removing Info links for ${FLAVOR}
-        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/info/ispack-ifc8.1.info.gz
+        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/info/ispack-fftw2-ifc9.info.gz
     fi
 
     echo remove/${PACKAGE}: purging byte-compiled files for ${FLAVOR}
